You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@subversion.apache.org by rh...@apache.org on 2010/06/08 01:44:01 UTC

svn commit: r952488 - /subversion/trunk/subversion/bindings/javahl/native/CreateJ.cpp

Author: rhuijben
Date: Mon Jun  7 23:44:01 2010
New Revision: 952488

URL: http://svn.apache.org/viewvc?rev=952488&view=rev
Log:
Following up on r952416, r952421 and r952427, hopefully fix a failing javahl
testcase.

* subversion/bindings/javahl/native/CreateJ.cpp
  (CreateJ::Status): Ignore entry not found errors.

Modified:
    subversion/trunk/subversion/bindings/javahl/native/CreateJ.cpp

Modified: subversion/trunk/subversion/bindings/javahl/native/CreateJ.cpp
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/bindings/javahl/native/CreateJ.cpp?rev=952488&r1=952487&r2=952488&view=diff
==============================================================================
--- subversion/trunk/subversion/bindings/javahl/native/CreateJ.cpp (original)
+++ subversion/trunk/subversion/bindings/javahl/native/CreateJ.cpp Mon Jun  7 23:44:01 2010
@@ -569,12 +569,20 @@ CreateJ::Status(svn_wc_context_t *wc_ctx
       const svn_wc_entry_t *entry = NULL;
 
       if (status->versioned)
-        /* ### This sets entry to NULL when svn_wc__get_entry() returns
-           ### SVN_ERR_NODE_UNEXPECTED_KIND!. Needs a workaround for 100%
-           ### compatibility with <= 1.6 */
-        SVN_JNI_ERR(svn_wc__get_entry_versioned(&entry, wc_ctx, local_abspath,
-                                                svn_node_unknown, FALSE, FALSE,
-                                                pool, pool), NULL);
+        {
+          /* ### This call returns SVN_ERR_ENTRY_NOT_FOUND for all not found
+             ### cases including the (for status) ignored 
+             ### SVN_ERR_NODE_UNEXPECTED_KIND!. Needs a workaround for 100%
+             ### compatibility with <= 1.6 */
+          svn_error_t *err = svn_wc__get_entry_versioned(&entry, wc_ctx, local_abspath,
+                                                         svn_node_unknown, FALSE, FALSE,
+                                                         pool, pool);
+
+          if (err && err->apr_err == SVN_ERR_ENTRY_NOT_FOUND)
+            svn_error_clear(err);
+          else
+            SVN_JNI_ERR(err, NULL);
+         }
 
       if (entry != NULL)
         {